@@ -1,4 +1,5 @@
 mod addr;
+mod any;
 mod tcp;
 mod unix;
 mod wss;
@@ -6,6 +7,8 @@ mod wss;
 pub use addr::*;
 pub use wss::*;
 
+pub use any::*;
+
 #[cfg(not(target_arch = "wasm32"))]
 pub use tcp::*;
 
